"use strict";

Object.defineProperty(exports, "__esModule", {
	value: true
});

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var accounting = require("accounting");
var moment = require("moment");

var defaultImage = "https://storage.googleapis.com/eezee-storage/eezee-homepage.jpg";

var getAboutUsPageInfo = exports.getAboutUsPageInfo = function getAboutUsPageInfo() {
	return {
		title: "About Us - Eezee",
		description: "Eezee is a Marketplace for all your business needs. Carrying over 10,000 products ranging from industrial goods and supplies to stationary. You are sure to find what you need in an instant.",
		image: defaultImage
	};
};

var getBreadCrumbJson = exports.getBreadCrumbJson = function getBreadCrumbJson(breadCrumbs) {
	return {

		"@context": "http://schema.org",
		"@type": "BreadcrumbList",
		"itemListElement": breadCrumbs.map(function (_bc, i) {
			return {
				"@type": "ListItem",
				"position": i + 1,
				"item": {
					"@id": _bc.link,
					"name": _bc.title
				}
			};
		})

		// [{
		// 	"@type": "ListItem",
		// 	"position": 1,
		// 	"item": {
		// 	"@id": "https://example.com/books",
		// 	"name": "Books",
		// 	"image": "http://example.com/images/icon-book.png"
		// 	}
		// },{
		// 	"@type": "ListItem",
		// 	"position": 2,
		// 	"item": {
		// 	"@id": "https://example.com/books/authors",
		// 	"name": "Authors",
		// 	"image": "http://example.com/images/icon-author.png"
		// 	}
		// },{
		// 	"@type": "ListItem",
		// 	"position": 3,
		// 	"item": {
		// 	"@id": "https://example.com/books/authors/annleckie",
		// 	"name": "Ann Leckie",
		// 	"image": "http://example.com/images/author-leckie-ann.png"
		// 	}
		// },{
		// 	"@type": "ListItem",
		// 	"position": 4,
		// 	"item": {
		// 	"@id": "https://example.com/books/authors/ancillaryjustice",
		// 	"name": "Ancillary Justice",
		// 	"image": "http://example.com/images/cover-ancillary-justice.png"
		// 	}
		// }]
	};
};

var getBrandPageInfo = exports.getBrandPageInfo = function getBrandPageInfo(_ref) {
	var productList = _ref.productList,
	    size = _ref.size,
	    _ref$page = _ref.page,
	    page = _ref$page === undefined ? false : _ref$page,
	    searchParam = _ref.searchParam;

	var _getBrand = getBrand(productList, searchParam),
	    brand = _getBrand.brand,
	    brandTitleCase = _getBrand.brandTitleCase;

	var _getCategoryName = getCategoryName(productList),
	    subCategoryName = _getCategoryName.subCategoryName;

	var aggregatePriceJSON = getAggregatePriceJSON({
		brand: brand,
		productList: productList,
		size: size,
		subCategoryName: subCategoryName
	});

	var title = brandTitleCase + " Singapore" + (page ? " Page " + page : "") + " - Best Price",
	    description = (page ? "Page " + page + " - " : "") + "Source and compare " + brandTitleCase + " products directly from " + brandTitleCase + " on Eezee Singapore. Bulk Discount & Wholesale Price.",
	    image = getImage(productList);

	return {
		title: title,
		description: description,
		searchParam: brandTitleCase,
		image: image,
		aggregatePriceJSON: aggregatePriceJSON
	};
};

var getCartPageInfo = exports.getCartPageInfo = function getCartPageInfo() {
	return {
		title: "Checkout Products - Eezee",
		description: "Procure hassle free today! Source products directly from authorised distributors on Eezee. Bulk Discount & Wholesale Price available!",
		image: defaultImage
	};
};

var getCategoriesPageInfo = exports.getCategoriesPageInfo = function getCategoriesPageInfo() {
	return {
		title: "All Product Categories - Eezee B2B Marketplace",
		description: "Browse all available Eezee Categories.",
		image: "https://storage.googleapis.com/eezee-storage/eezee-search.jpg"
	};
};

var getContactUsPageInfo = exports.getContactUsPageInfo = function getContactUsPageInfo() {
	return {
		title: "Contact Us - Eezee",
		description: "We read every email and take every call. We typically reply in minutes! Contact us today!",
		image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
	};
};

var getEmailVerficationPageInfo = exports.getEmailVerficationPageInfo = function getEmailVerficationPageInfo() {
	return {
		title: "Verify Email - Eezee",
		description: "Verify your email to use Eezee",
		image: "https://storage.googleapis.com/eezee-storage/verify-email.png"
	};
};

var getForgetPasswordSuccessPageInfo = exports.getForgetPasswordSuccessPageInfo = function getForgetPasswordSuccessPageInfo() {
	return {
		title: "Forget Password (Success) - Eezee",
		description: "A verification email has been sent to you.",
		image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
	};
};

var getForgetPasswordPageInfo = exports.getForgetPasswordPageInfo = function getForgetPasswordPageInfo() {
	return {
		title: "Forget Password - Eezee",
		description: "Please enter your email address below to reset your password. Check your inbox and click on the link we have sent to enter a new password.",
		image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
	};
};

var getHomePageInfo = exports.getHomePageInfo = function getHomePageInfo() {
	return {
		title: "Eezee B2B Marketplace - Making Procurement Easy",
		description: "Procure hassle free today! Source products directly from authorised distributors, suppliers and wholesalers on Eezee B2B Marketplace. Bulk Discount and  Wholesale Price available!",
		image: defaultImage
	};
};

var getLoginPageInfo = exports.getLoginPageInfo = function getLoginPageInfo() {
	return {
		title: "Login - Eezee",
		description: "Login or Signup on Eezee B2B Marketplace today! Free to list only charged on sale!",
		image: "https://storage.googleapis.com/eezee-storage/eezee-login.jpg"
	};
};

var getPaymentPageInfo = exports.getPaymentPageInfo = function getPaymentPageInfo() {
	return {
		title: "Payment (Last Step) - Eezee",
		description: "Choose between Paypal, Visa/Master or Bank transfer as your mode of payment.",
		image: defaultImage
	};
};

var getPaymentPageSuccessInfo = exports.getPaymentPageSuccessInfo = function getPaymentPageSuccessInfo() {
	return {
		title: 'Payment Success - Eezee',
		description: "Your payment has been approved!",
		image: 'https://storage.googleapis.com/eezee-storage/eezee-successful-payment.png'
	};
};

var getPrivacyPolicyInfo = exports.getPrivacyPolicyInfo = function getPrivacyPolicyInfo() {
	return {
		title: "Privacy Policy - Eezee",
		description: "At Eezee, we collect and manage user data according to the following Privacy Policy, with the goal of incorporating our company values: transparency and integrity.",
		image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
	};
};

var getProductDetailsPageInfo = exports.getProductDetailsPageInfo = function getProductDetailsPageInfo(product) {
	var currency = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "SGD";


	var title = product.title + " Singapore - Eezee",
	    image = product.images[0].url;

	var breadCrumbArray = void 0,
	    breadCrumbSchema = void 0;
	breadCrumbArray = [{
		link: "https://eezee.sg",
		title: "https://eezee.sg"
	}, {
		link: "https://eezee.sg/" + product.categories.mainKebabCase + "/" + product.categories.subKebabCase,
		title: product.categories.sub
	}];

	if (product.brand && product.brand.name) {
		breadCrumbArray.push({
			link: "https://eezee.sg/brand/" + product.brand.kebabName,
			title: product.brand.name
		});
	}

	breadCrumbSchema = getBreadCrumbJson(breadCrumbArray);

	var description = "Buy and compare " + (product.brand && product.brand.name + " " || "" + product.title + (product.model.length < 15 && !product.title.includes(product.model) ? " " + product.model + " " : " ")) + "products on Eezee Singapore, the largest online industrial hardware superstore.";

	var productPriceValue = product.price[currency].value;

	if (currency === "SGD") {
		productPriceValue = productPriceValue * 1.07;
	}

	var priceFormatted = accounting.formatMoney(productPriceValue, "", product.price[currency].dp, "", ".");

	var domainName = getDomainName(currency);
	var url = "https://" + domainName + "/product/" + product.uniqTitle + "-" + product.sku;

	var productSchema = JSON.stringify({
		"@context": "http://schema.org/",
		"@type": "Product",
		"productID": product.sku,
		"name": product.title,
		"description": description,
		"image": product.images.map(function (image) {
			return "https://api.eezee.sg/api/images/resize?height=500&width=500&url=" + image.url;
		}),
		"url": url,
		"mpn": product.model || "NIL",
		"brand": product.brand && product.brand.name || "No Brand",
		"offers": [{
			"@type": "Offer",
			"priceCurrency": currency,
			"price": priceFormatted,
			"itemCondition": "https://schema.org/NewCondition",
			"availability": "http://schema.org/InStock",
			"url": url,
			"priceValidUntil": moment().add(1, "month").format("YYYY-MM-DD")
		}]
	});

	if (product.bulkDiscount.length > 0) {
		var sortedBd = product.bulkDiscount.sort(function (a, b) {
			return b.discount - a.discount;
		});

		description = "Up to " + sortedBd[0].discount + "% Off - " + description;
	}

	return {
		title: title,
		description: description,
		image: image,
		productSchema: productSchema,
		breadCrumbSchema: breadCrumbSchema
	};
};

var getResetPasswordPageInfo = exports.getResetPasswordPageInfo = function getResetPasswordPageInfo() {
	return {
		title: "Reset Password - Eezee",
		description: "New Password | Repeat New Password",
		image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
	};
};

var getSearchPageInfo = exports.getSearchPageInfo = function getSearchPageInfo(_ref2) {
	var productList = _ref2.productList,
	    size = _ref2.size,
	    _ref2$page = _ref2.page,
	    page = _ref2$page === undefined ? false : _ref2$page,
	    searchParam = _ref2.searchParam;

	var _getCategoryName2 = getCategoryName(productList),
	    subCategoryName = _getCategoryName2.subCategoryName;

	var _getBrand2 = getBrand(productList),
	    brand = _getBrand2.brand;

	var aggregatePriceJSON = getAggregatePriceJSON({
		productList: productList,
		size: size,
		subCategoryName: subCategoryName,
		brand: brand
	});

	var title = getTitleCase(searchParam) + " - Eezee B2B Marketplace",
	    description = (page ? "Page " + page + " - " : "") + "Compare prices from different suppliers, wholesalers and distributors for " + getTitleCase(searchParam) + " on Eezee.",
	    image = getImage(productList);

	return {
		title: title,
		description: description,
		searchParam: searchParam,
		image: image,
		aggregatePriceJSON: aggregatePriceJSON
	};
};

var getStoreNicheCategoryText = exports.getStoreNicheCategoryText = function getStoreNicheCategoryText(categoryNiche) {
	switch (categoryNiche.length) {
		case 1:
			return categoryNiche[0].name;

		case 2:
			return categoryNiche[0].name + " & " + categoryNiche[1].name;

		case 3:
			return categoryNiche[0].name + ", " + categoryNiche[1].name + " & " + categoryNiche[2].name;

		default:
			break;
	}
};

var getStorePageInfo = exports.getStorePageInfo = function getStorePageInfo(_ref3) {
	var productList = _ref3.productList,
	    size = _ref3.size,
	    searchParam = _ref3.searchParam,
	    _ref3$page = _ref3.page,
	    page = _ref3$page === undefined ? false : _ref3$page,
	    categoryNiche = _ref3.categoryNiche,
	    companyName = _ref3.companyName,
	    _ref3$pageType = _ref3.pageType,
	    pageType = _ref3$pageType === undefined ? "store" : _ref3$pageType;

	var _getCategoryName3 = getCategoryName(productList),
	    subCategoryName = _getCategoryName3.subCategoryName;

	var _getBrand3 = getBrand(productList),
	    brand = _getBrand3.brand;

	var aggregatePriceJSON = getAggregatePriceJSON({
		brand: brand,
		productList: productList,
		size: size,
		subCategoryName: subCategoryName
	});

	var categoryText = getStoreNicheCategoryText(categoryNiche),
	    _companyName = getTitleCase(companyName);

	var title = "Eezee Store " + searchParam + " | " + _companyName + (page ? " - Page " + page : ""),
	    description = (page ? "Page " + page + " - " : "") + "Eezee Supplier " + searchParam + " stocks reputable brands for " + categoryText + " in Singapore. Shop with us now!",
	    image = getImage(productList);

	if (pageType === 'company') {
		title = _companyName + " | Eezee" + (page ? " - Page " + page : "");
	}

	return {
		title: title,
		description: description,
		searchParam: searchParam,
		image: image,
		aggregatePriceJSON: aggregatePriceJSON
	};
};

var getSubCategoryInfo = exports.getSubCategoryInfo = function getSubCategoryInfo(_ref4) {
	var productList = _ref4.productList,
	    size = _ref4.size,
	    page = _ref4.page;

	var _getCategoryName4 = getCategoryName(productList),
	    subCategoryName = _getCategoryName4.subCategoryName,
	    mainCategoryName = _getCategoryName4.mainCategoryName;

	var _getBrand4 = getBrand(productList),
	    brand = _getBrand4.brand;

	var aggregatePriceJSON = getAggregatePriceJSON({
		brand: brand,
		productList: productList,
		size: size,
		subCategoryName: subCategoryName
	});

	var title = subCategoryName + " - Credit Terms Available - Eezee";
	var description = (page ? "Page " + page + " - " : "") + "Source and compare " + subCategoryName + " directly from authorised distributors on Eezee.";
	var image = getImage(productList);
	var searchParam = subCategoryName;

	return {
		title: title,
		description: description,
		searchParam: searchParam,
		image: image,
		aggregatePriceJSON: aggregatePriceJSON
	};
};

var getTermsAndConditionsInfo = exports.getTermsAndConditionsInfo = function getTermsAndConditionsInfo() {
	return {
		title: "Terms Of Use - Eezee",
		description: "By accepting this User Agreement, you agree that this User Agreement applies when using the website and services available.",
		image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
	};
};

// -----------------------------------------------------------------------------------------------------------------------
var getAggregatePriceJSON = exports.getAggregatePriceJSON = function getAggregatePriceJSON(_ref5) {
	var brand = _ref5.brand,
	    productList = _ref5.productList,
	    size = _ref5.size,
	    subCategoryName = _ref5.subCategoryName;


	if (productList.length === 0) {
		return '';
	}

	var lowHighPrice = productList.reduce(getLowHighPrice, { low: 10000, high: 0 });

	var topThreeImages = [].concat(_toConsumableArray(productList.slice(0, 3).reduce(function (acc, cur) {
		return acc.concat(cur.images);
	}, [])));

	var categoryPageSchema = {
		"@context": "http://schema.org/",
		"@type": "Product",
		"name": subCategoryName,
		"image": topThreeImages.map(function (image) {
			return image.url;
		}),
		"offers": {
			"@type": "AggregateOffer",
			"lowPrice": lowHighPrice.low,
			"highPrice": lowHighPrice.high,
			"priceCurrency": "SGD",
			"offerCount": size
		}
	};

	if (brand) {
		categoryPageSchema.brand = {
			"@type": "Thing",
			"name": brand
		};
	}

	return JSON.stringify(categoryPageSchema);
};

var getBrand = exports.getBrand = function getBrand(productList, searchParam) {

	var brand = void 0,
	    brandTitleCase = void 0;

	productList = productList.filter(function (product) {
		return product.brand;
	});

	if (productList.length === 0 && searchParam) {

		brand = searchParam;
		brandTitleCase = getTitleCase(searchParam);

		return { brand: brand, brandTitleCase: brandTitleCase };
	}

	for (var i = 0; i < productList.length; i++) {

		if (productList[i].brand && productList[i].brand.name) {

			brand = productList[i].brand.name;
			brandTitleCase = getTitleCase(productList[i].brand.name);
			break;
		}

		if (i === productList.length && !brandTitleCase) {
			brandTitleCase = 'OEM';
			brand = 'Original Equipment Manufacturer';
			break;
		}
	}

	return { brand: brand, brandTitleCase: brandTitleCase };
};

var getCategoryName = exports.getCategoryName = function getCategoryName(productList) {

	var subMainCategory = productList.filter(function (product) {
		return product.categories.sub;
	}).reduce(function (acc, cur) {
		if (!acc.subCategoryName) {
			acc.subCategoryName = cur.categories.sub || false;
		}

		if (!acc.mainCategoryName) {
			acc.mainCategoryName = cur.categories.main || false;
		}

		return acc;
	}, { subCategoryName: false, mainCategoryName: false });

	// const subCategoryName = productList.length > 0 ? productList[0].categories.sub || "OEM" : "OEM";
	// const mainCategoryName = productList.length > 0 ? productList[0].categories.sub || "OEM" : "OEM";

	return {
		subCategoryName: subMainCategory.subCategoryName || "OEM",
		mainCategoryName: subMainCategory.mainCategoryName || false
	};
};

var getDomainName = exports.getDomainName = function getDomainName() {
	var currency = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "SGD";


	var topLevelDomain = "eezee.sg";

	switch (currency) {

		case "IDR":
			topLevelDomain = "id." + topLevelDomain;
			break;

		case "USD":
			topLevelDomain = "us." + topLevelDomain;
			break;

		case "CNY":
			topLevelDomain = "cn." + topLevelDomain;
			break;

		case "MYR":
			topLevelDomain = "my." + topLevelDomain;
			break;

		case "AUD":
			topLevelDomain = "au." + topLevelDomain;
			break;

		case "PHP":
			topLevelDomain = "ph." + topLevelDomain;
			break;

	}

	return topLevelDomain;
};

var getImage = exports.getImage = function getImage(productList) {

	var image = productList.filter(function (product) {
		return product.images.length > 0;
	});

	// first product's first image
	if (image.length > 0) {
		image = image[0].images && image[0].images.length > 0 ? image[0].images[0].url : 'https://eezee.sg/static/eezee-product.svg';
	} else {
		image = "https://eezee.sg/static/eezee-product.svg";
	}

	return image;
};

var getLowHighPrice = exports.getLowHighPrice = function getLowHighPrice(acc, cur) {

	if (cur.price.original === 0) {
		return acc;
	}

	if (acc.low > cur.price.original) {
		acc.low = cur.price.original;
	}

	if (acc.high < cur.price.original) {
		acc.high = cur.price.original;
	}

	return acc;
};

var getTitleCase = exports.getTitleCase = function getTitleCase(str) {
	return str.replace(/\w\S*/g, function (txt) {
		return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
	});
};