// const redis = require('redis');
const Redis = require('ioredis');
const q = require('q');

export class RedisCache {

	constructor({ host, port, password, masterName }){

		this.host = host;
		this.port = port;
		this.password = password;
		this.masterName = masterName;

		this.connect();
	}

	connect(){

		if( this.host.length === 1 ){
			
			this.redisCache = new Redis({
				port: this.port,   // Redis port
				host: this.host[0],   // Redis host
				password: this.password,
				retryStrategy: function (times) {

					var delay = Math.min(times * 1000, 20000);
					console.log( delay );
					return delay;

				}
			});

		} else {
			// Redis
			this.redisCache = new Redis({
				sentinels: this.host.map(
					( h, i ) => ({
						port: this.port[i],
						host: h
					})
				),
				name: this.masterName,
				password: this.password,
				retryStrategy: function (times) {
					var delay = Math.min(times * 50, 2000);
					console.log( delay );
					return delay;
				}
			});
			
			// Redis.Cluster(

			// 	this.host.map(
			// 		( h, i ) => ({
			// 			port: this.port[i],
			// 			host: h
			// 		})
			// 	),
				
			// 	{
			// 		clusterRetryStrategy: ( times ) => {
			// 			var delay = Math.min(100 + times * 2, 2000);
			// 			return delay;
			// 		},
			// 		redisOptions: {
			// 			password: this.password
			// 		}
			// 	}

			// );
			
		}

		// this.redisCache = redis.createClient({
		// 	host: this.host,
		// 	port: this.port,
		// 	retry_strategy: function (options) {
		// 		if (options.error && options.error.code === 'ECONNREFUSED') {
		// 				// End reconnecting on a specific error and flush all commands with
		// 				// a individual error
		// 				return new Error('The server refused the connection');
		// 		}
		// 		if (options.total_retry_time > 1000 * 60 * 60) {
		// 				// End reconnecting after a specific timeout and flush all commands
		// 				// with a individual error
		// 				return new Error('Retry time exhausted');
		// 		}
		// 		if (options.attempt > 100) {
		// 				// End reconnecting with built in error
		// 				return undefined;
		// 		}
		// 		// reconnect after
		// 		return Math.min(options.attempt * 100, 3000);
		// 	}
		
		// });
	}

	del( key ){
		let promise = q.defer();

		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		this.redisCache.del( key, ( err, data ) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}
			
			promise.resolve( data );
		});

		return promise.promise;
  }
  
  keys( pattern ){

		let promise = q.defer();

		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		// redisCache.exist( key, )
		this.redisCache.keys( pattern, ( err, data ) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}
			
			promise.resolve( data );
		})

		// this.redisCache.exist( key, ( err, data ) => {
		// 	if(err){
		// 		promise.reject(err);
		// 		return promise.promise;
		// 	}

		// 	promise.resolve( data );
		// });

		return promise.promise;

	}

	exist( key ){

		let promise = q.defer();

		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		// redisCache.exist( key, )
		this.redisCache.exists( key, ( err, data ) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}
			
			promise.resolve( data );
		})

		// this.redisCache.exist( key, ( err, data ) => {
		// 	if(err){
		// 		promise.reject(err);
		// 		return promise.promise;
		// 	}

		// 	promise.resolve( data );
		// });

		return promise.promise;

	}

	get( key ){

		let promise = q.defer();

		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		this.redisCache.get( key, ( err, data ) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}

			promise.resolve( data );
		});

		return promise.promise;

	}

	// hset( key, value ){

	// 	let promise = q.defer();

	// 	this.redisCache.hset( key, objKey, value, (err, reply) => {
	// 		if(err){
	// 			promise.reject(err);
	// 			return promise.promise;
	// 		}

	// 		promise.resolve( reply );
	// 	});

	// 	return promise.promise;

	// }

	set( key, value, ex = false ){

		let promise = q.defer();
		
		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		if( ex ){

			this.redisCache.set( key, value, 'EX', ex, (err, reply) => {
				if(err){
					promise.reject(err);
					return promise.promise;
				}
	
				promise.resolve( reply );
			});
	
		} else {
			this.redisCache.set( key, value, (err, reply) => {
				if(err){
					promise.reject(err);
					return promise.promise;
				}
	
				promise.resolve( reply );
			});
	
		}
		
		return promise.promise;

	}

	setObj( key, value ){
		
		let promise = q.defer();

		// value
		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}
			
		this.redisCache.hmset( key, value, (err, reply) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}

			promise.resolve( reply );
		});

		return promise.promise;

	}

	getObj( key ){
		
		let promise = q.defer();

		if(this.redisCache.status === 'reconnecting'){
			promise.reject({
				msg: 'Redis not connected'
			});
			return promise.promise;
		}

		this.redisCache.hgetall( key, (err, reply) => {
			if(err){
				promise.reject(err);
				return promise.promise;
			}

			if( Object.keys(reply).length === 0 ){
				promise.resolve( null );	
				return promise.promise;
			}

			promise.resolve( reply );
		});

		return promise.promise;

	}
}