const accounting = require("accounting");
const moment = require("moment");

const defaultImage = "https://storage.googleapis.com/eezee-storage/eezee-homepage.jpg";

export const getAboutUsPageInfo = () => ({
	title: ("About Us - Eezee"),
	description: ("Eezee is a Marketplace for all your business needs. Carrying over 10,000 products ranging from industrial goods and supplies to stationary. You are sure to find what you need in an instant."),
	image: defaultImage
})

export const getBreadCrumbJson = ( breadCrumbs ) => ({

	"@context": "http://schema.org",
	"@type": "BreadcrumbList",
	"itemListElement": breadCrumbs.map(
		(_bc, i) => ({
			"@type": "ListItem",
			"position": i + 1,
			"item": {
				"@id": _bc.link,
				"name": _bc.title
			}
		})
	)

	// [{
	// 	"@type": "ListItem",
	// 	"position": 1,
	// 	"item": {
	// 	"@id": "https://example.com/books",
	// 	"name": "Books",
	// 	"image": "http://example.com/images/icon-book.png"
	// 	}
	// },{
	// 	"@type": "ListItem",
	// 	"position": 2,
	// 	"item": {
	// 	"@id": "https://example.com/books/authors",
	// 	"name": "Authors",
	// 	"image": "http://example.com/images/icon-author.png"
	// 	}
	// },{
	// 	"@type": "ListItem",
	// 	"position": 3,
	// 	"item": {
	// 	"@id": "https://example.com/books/authors/annleckie",
	// 	"name": "Ann Leckie",
	// 	"image": "http://example.com/images/author-leckie-ann.png"
	// 	}
	// },{
	// 	"@type": "ListItem",
	// 	"position": 4,
	// 	"item": {
	// 	"@id": "https://example.com/books/authors/ancillaryjustice",
	// 	"name": "Ancillary Justice",
	// 	"image": "http://example.com/images/cover-ancillary-justice.png"
	// 	}
	// }]
})

export const getBrandPageInfo = ({ productList, size, page = false, searchParam }) => {

	const { brand, brandTitleCase } = getBrand( productList, searchParam);
	const { subCategoryName } = getCategoryName( productList );
	const aggregatePriceJSON = getAggregatePriceJSON({
		brand,
		productList, 
		size,
		subCategoryName
	});

	let 	title = (`${brandTitleCase} Singapore${page? ` Page ${page}`: `` } - Best Price`),
				description = (`${page? `Page ${page} - `: `` }Source and compare ${brandTitleCase} products directly from ${brandTitleCase} on Eezee Singapore. Bulk Discount & Wholesale Price.`),
				image = getImage( productList );

	return {
		title,
		description,
		searchParam: brandTitleCase,
		image,
		aggregatePriceJSON
	}
}

export const getCartPageInfo = () => ({
	title: ("Checkout Products - Eezee"),
	description: ("Procure hassle free today! Source products directly from authorised distributors on Eezee. Bulk Discount & Wholesale Price available!"),
	image: defaultImage,
})

export const getCategoriesPageInfo = () => ({
	title: ("All Product Categories - Eezee B2B Marketplace"),
	description: ("Browse all available Eezee Categories."),
	image: "https://storage.googleapis.com/eezee-storage/eezee-search.jpg"
})

export const getContactUsPageInfo = () => ({
	title: ("Contact Us - Eezee"),
	description: ("We read every email and take every call. We typically reply in minutes! Contact us today!"),
	image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
})

export const getEmailVerficationPageInfo = () => ({
	title: ("Verify Email - Eezee"),
	description: ("Verify your email to use Eezee"),
	image: "https://storage.googleapis.com/eezee-storage/verify-email.png"
})

export const getForgetPasswordSuccessPageInfo = () => ({
	title: ("Forget Password (Success) - Eezee"),
	description: ("A verification email has been sent to you."),
	image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
})

export const getForgetPasswordPageInfo = () => ({
	title: ("Forget Password - Eezee"),
	description: ("Please enter your email address below to reset your password. Check your inbox and click on the link we have sent to enter a new password."),
	image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
})

export const getHomePageInfo = () => {
	return {
		title: ("Eezee B2B Marketplace - Making Procurement Easy"),
		description: ("Procure hassle free today! Source products directly from authorised distributors, suppliers and wholesalers on Eezee B2B Marketplace. Bulk Discount and  Wholesale Price available!"),
		image: defaultImage
	}
}

export const getLoginPageInfo = () => {
	return {
		title: ("Login - Eezee"),
		description: ("Login or Signup on Eezee B2B Marketplace today! Free to list only charged on sale!"),
		image: "https://storage.googleapis.com/eezee-storage/eezee-login.jpg"
	}
}

export const getPaymentPageInfo = () => ({
	title: ("Payment (Last Step) - Eezee"),
	description: ("Choose between Paypal, Visa/Master or Bank transfer as your mode of payment."),
	image: defaultImage
})

export const getPaymentPageSuccessInfo = () => ({
	title: ('Payment Success - Eezee'),
	description: ("Your payment has been approved!"),
	image: 'https://storage.googleapis.com/eezee-storage/eezee-successful-payment.png'
})

export const getPrivacyPolicyInfo = () => {
	return {
		title: ("Privacy Policy - Eezee"),
		description: ("At Eezee, we collect and manage user data according to the following Privacy Policy, with the goal of incorporating our company values: transparency and integrity."),
		image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
	}
}


export const getProductDetailsPageInfo = ( product, currency = "SGD" ) => {

	let title = (`${product.title} Singapore - Eezee`),
		image = product.images[0].url;
				
	let breadCrumbArray, breadCrumbSchema;
	breadCrumbArray = [
		{
			link: "https://eezee.sg",
			title: "https://eezee.sg"
		},
		{
			link: `https://eezee.sg/${product.categories.mainKebabCase}/${product.categories.subKebabCase}`,
			title: product.categories.sub
		}
	];

	if( product.brand && product.brand.name ){
		breadCrumbArray.push({
			link: `https://eezee.sg/brand/${product.brand.kebabName}`,
			title: product.brand.name
		})
	}

	breadCrumbSchema = getBreadCrumbJson( breadCrumbArray );

	let description = (`Buy and compare ${(product.brand && `${product.brand.name} ` || `${product.title}${product.model.length < 15 && !product.title.includes(product.model)? 
		` ${product.model} `: 
		` `
	}`)}products on Eezee Singapore, the largest online industrial hardware superstore.`);

	let productPriceValue = product.price[currency].value;

	if( currency === "SGD" ){
		productPriceValue = productPriceValue * 1.07;
	}

	let priceFormatted = accounting.formatMoney(
		productPriceValue, 
		"",
		product.price[currency].dp,
		"",
		"."
	);

	let domainName = getDomainName( currency );
	let url = (`https://${domainName}/product/${product.uniqTitle}-${product.sku}`);

	let productSchema = JSON.stringify({
		"@context": "http://schema.org/",
		"@type": "Product",
		"productID": (product.sku),
		"name": (product.title),
		"description": (description),
		"image": product.images.map( image => `https://api.eezee.sg/api/images/resize?height=500&width=500&url=${image.url}` ),
		"url": (url),
		"mpn": (product.model || "NIL"),
		"brand": (product.brand && product.brand.name || "No Brand"),
		"offers": [
			{
				"@type": "Offer",
				"priceCurrency": currency,
				"price": priceFormatted,
				"itemCondition": "https://schema.org/NewCondition",
				"availability": "http://schema.org/InStock",
				"url": url,
				"priceValidUntil": moment().add(1,"month").format("YYYY-MM-DD")
			}
		]
	});

	if( product.bulkDiscount.length > 0 ){
		const sortedBd = product.bulkDiscount.sort((a,b) => b.discount - a.discount);

		description = `Up to ${sortedBd[0].discount}% Off - ${description}`;
	}

	return {
		title,
		description,
		image,
		productSchema,
		breadCrumbSchema
	}
}

export const getResetPasswordPageInfo = () => ({
	title: ("Reset Password - Eezee"),
	description: ("New Password | Repeat New Password"),
	image: "https://storage.googleapis.com/eezee-storage/eezee-forget-pw.png"
})

export const getSearchPageInfo = ({ productList, size, page = false, searchParam }) => {

	const { subCategoryName } = getCategoryName( productList );
	const { brand } = getBrand( productList );

	const aggregatePriceJSON = getAggregatePriceJSON({ 
		productList, 
		size,
		subCategoryName,
		brand
	});

	let title = `${getTitleCase(searchParam)} - Eezee B2B Marketplace`,
			description = `${page? `Page ${page} - `: `` }Compare prices from different suppliers, wholesalers and distributors for ${getTitleCase(searchParam)} on Eezee.`,
			image = getImage( productList );

	return {
		title,
		description,
		searchParam,
		image,
		aggregatePriceJSON
	}

}

export const getStoreNicheCategoryText = ( categoryNiche ) => {
	switch(categoryNiche.length){
		case 1:
			return categoryNiche[0].name;

		case 2:
			return `${categoryNiche[0].name} & ${categoryNiche[1].name}`;

		case 3:
			return `${categoryNiche[0].name}, ${categoryNiche[1].name} & ${categoryNiche[2].name}`;

		default:
			break;
	}
}

export const getStorePageInfo = ({ productList, size, searchParam, page = false, categoryNiche, companyName, pageType = "store" }) => {
	
	const { subCategoryName } = getCategoryName( productList );
	const { brand } = getBrand( productList );

	const aggregatePriceJSON = getAggregatePriceJSON({
		brand,
		productList, 
		size,
		subCategoryName
	});

	let categoryText = getStoreNicheCategoryText( categoryNiche ),
			_companyName = getTitleCase( companyName );

	let 	title = `Eezee Store ${searchParam} | ${_companyName}${page? ` - Page ${page}`: `` }`,
				description = `${page? `Page ${page} - `: `` }Eezee Supplier ${searchParam} stocks reputable brands for ${categoryText} in Singapore. Shop with us now!`,
				image = getImage( productList );

	if( pageType === 'company'){
		title = `${_companyName} | Eezee${page? ` - Page ${page}`: `` }`
	}

	return {
		title,
		description,
		searchParam,
		image,
		aggregatePriceJSON
	}
}

export const getSubCategoryInfo = ({ productList, size, page }) => {

	
	const { subCategoryName, mainCategoryName } = getCategoryName( productList );
	const { brand } = getBrand( productList );

	const aggregatePriceJSON = getAggregatePriceJSON({ 
		brand,
		productList, 
		size,
		subCategoryName
	});

	const title = `${subCategoryName} - Credit Terms Available - Eezee`;
	const description = (`${page? `Page ${page} - `: `` }Source and compare ${subCategoryName} directly from authorised distributors on Eezee.`);
	const image = getImage( productList );
	const searchParam = subCategoryName;
	
	return {
		title,
		description,
		searchParam,
		image,
		aggregatePriceJSON
	}

}

export const getTermsAndConditionsInfo = () => {
	return {
		title: ("Terms Of Use - Eezee"),
		description: ("By accepting this User Agreement, you agree that this User Agreement applies when using the website and services available."),
		image: "https://storage.googleapis.com/eezee-storage/eezee-team-min.JPG"
	}
}


// -----------------------------------------------------------------------------------------------------------------------
export const getAggregatePriceJSON = ({ brand, productList, size, subCategoryName }) => {

	if(productList.length === 0){
		return '';
	}

	const lowHighPrice = productList.reduce(getLowHighPrice, { low:10000, high: 0 });

	const topThreeImages = [...productList.slice(0,3).reduce(
		(acc, cur) => acc.concat(cur.images)
		,[]
	)];

	let categoryPageSchema = {
		"@context": "http://schema.org/",
		"@type": "Product",
		"name": subCategoryName,
		"image": topThreeImages.map( image => image.url ),
		"offers": {
			"@type": "AggregateOffer",
			"lowPrice": lowHighPrice.low,
			"highPrice": lowHighPrice.high,
			"priceCurrency": "SGD",
			"offerCount": size
		}
	}

	if( brand ){
		categoryPageSchema.brand = {
			"@type": "Thing",
			"name": (brand)
		}
	}

	return JSON.stringify(categoryPageSchema);
}

export const getBrand = ( productList, searchParam ) => {	

	let 	brand,
				brandTitleCase;

	productList = productList.filter( product => product.brand );
	
	if( productList.length === 0 && searchParam){

		brand = searchParam;
		brandTitleCase = getTitleCase(searchParam);

		return { brand, brandTitleCase };	
	}

	for( let i = 0; i < productList.length; i++){
		
		if(productList[i].brand && productList[i].brand.name){
			
			brand = productList[i].brand.name;
			brandTitleCase = getTitleCase(productList[i].brand.name);
			break;
		}

		if( i === productList.length && !brandTitleCase){
			brandTitleCase = 'OEM';
			brand = 'Original Equipment Manufacturer';
			break;
		}

	}

	return { brand, brandTitleCase };
}

export const getCategoryName = ( productList ) => {
	
	const subMainCategory = productList	
														.filter( product => product.categories.sub )
														.reduce(
															(acc, cur) => {
																if(!acc.subCategoryName){
																	acc.subCategoryName = cur.categories.sub || false;
																}

																if(!acc.mainCategoryName){
																	acc.mainCategoryName = cur.categories.main || false;
																}

																return acc;
															}, 
															{ subCategoryName: false, mainCategoryName: false }
														);

	// const subCategoryName = productList.length > 0 ? productList[0].categories.sub || "OEM" : "OEM";
	// const mainCategoryName = productList.length > 0 ? productList[0].categories.sub || "OEM" : "OEM";

	return {
		subCategoryName: subMainCategory.subCategoryName || "OEM",
		mainCategoryName: subMainCategory.mainCategoryName || false
	};
}

export const getDomainName = ( currency = "SGD" ) => {

	let topLevelDomain = "eezee.sg";

	switch( currency ){

		case "IDR":
			topLevelDomain = `id.${topLevelDomain}`;
			break;

		case "USD":
			topLevelDomain = `us.${topLevelDomain}`;
			break;

		case "CNY":
			topLevelDomain = `cn.${topLevelDomain}`;
			break;
	
		case "MYR":
			topLevelDomain = `my.${topLevelDomain}`;
			break;

		case "AUD":
			topLevelDomain = `au.${topLevelDomain}`;
			break;

		case "PHP":
			topLevelDomain = `ph.${topLevelDomain}`;
			break;
	
	}

	return topLevelDomain;

}

export const getImage = ( productList ) => {

	let image = productList.filter( product => product.images.length > 0 );

	// first product's first image
	if(image.length > 0){
		image = image[0].images && image[0].images.length > 0 ? image[0].images[0].url : 'https://eezee.sg/static/eezee-product.svg';
	} else {	
		image = "https://eezee.sg/static/eezee-product.svg";
	}

	return image;

}

export const getLowHighPrice = ( acc, cur ) => {

	if(cur.price.original === 0){
		return acc;
	}

	if(acc.low > cur.price.original){
		acc.low = cur.price.original;
	}

	if(acc.high < cur.price.original){
		acc.high = cur.price.original;
	}

	return acc;
}

export const getTitleCase = (str) => {
	return str.replace(/\w\S*/g, function(txt){return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();});
}